agent

package
v0.23.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2025 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Decrypt

func Decrypt(socket string, data []byte) ([]byte, error)

Decrypt sends a DECRYPT command to the agent to decrypt the provided data.

func Message

func Message(socket string, args ...string) ([]byte, error)

func Ping

func Ping(socket string) error

Ping sends a PING command to the agent to check if it's running and responsive.

func Run

func Run(socket string, expire time.Duration) error

Run starts the agent server, listening for commands on the specified Unix socket. It handles decryption requests and manages identities.

func StartProcess

func StartProcess(executable string, expire time.Duration, memlock bool, socket, identitiesText string) error

StartProcess launches the agent executable in the background. It waits for the agent to become available and then sends it the identities.

Types

This section is empty.

Jump to